'use strict'

/** @typedef {import('@adonisjs/framework/src/Request')} Request */
/** @typedef {import('@adonisjs/framework/src/Response')} Response */
/** @typedef {import('@adonisjs/framework/src/View')} View */
const OrganizationType = use('App/Models/OrganizationType')
const { validate } = use('Validator')
const Env = use('Env')

/**
 * Resourceful controller for interacting with organizationtypes
 */
class OrganizationTypeController {
  /**
   * Show a list of all organizationtypes.
   * GET organizationtypes
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   * @param {View} ctx.view
   */
  async index ({ request, response, view }) {
    const types = await OrganizationType.all()
  
    return view.render('organization_types.index', {
      types: types.toJSON()
    })
  }

  /**
   * Render a form to be used for creating a new organizationtype.
   * GET organizationtypes/create
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   * @param {View} ctx.view
   */
  async create ({ request, response, view }) {
    return view.render('organization_types.create')
  }

  /**
   * Create/save a new organizationtype.
   * POST organizationtypes
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   */
  async store ({ request, response }) {
    const data = request.only(['type'])

    const validation = await validate(request.all(), {
      type: 'required',
    }, {
      'type.required': `Organization type is required`,
    })

    if(validation.fails()) {
      session.withErrors(validation.messages()).flashAll()
      return response.redirect('back')
    }

    await OrganizationType.create(data)

    return response.redirect(Env.get('APP_URL') + '/organization_types')
  }

  /**
   * Display a single organizationtype.
   * GET organizationtypes/:id
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   * @param {View} ctx.view
   */
  async show ({ params, request, response, view }) {
  }

  /**
   * Render a form to update an existing organizationtype.
   * GET organizationtypes/:id/edit
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   * @param {View} ctx.view
   */
  async edit ({ params, request, response, view }) {
  }

  /**
   * Update organizationtype details.
   * PUT or PATCH organizationtypes/:id
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   */
  async update ({ params, request, response }) {
  }

  /**
   * Delete a organizationtype with id.
   * DELETE organizationtypes/:id
   *
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Response} ctx.response
   */
  async destroy ({ params, request, response }) {
    const type = await OrganizationType.findOrFail(params.id)
    await type.delete()

    return response.redirect(Env.get('APP_URL') + '/organization_types')
  }
}

module.exports = OrganizationTypeController
